@@ -1,4 +1,4 @@
-/* $Id: write.c,v 1.19 2005/06/06 12:33:42 bdejean Exp $ */
+/* $Id: write.c,v 1.20 2006/04/10 08:41:46 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -39,7 +39,7 @@ glibtop_write_l (glibtop *server, size_t size, void *buf)
 	if (size == 0) return;
 
 #ifdef DEBUG
-	fprintf (stderr, "LIBRARY: really writing %d bytes.\n", size);
+	fprintf (stderr, "LIBRARY: really writing %d bytes.\n", (int)size);
 #endif
 
 	if (server->socket) {
@@ -49,5 +49,8 @@ glibtop_write_l (glibtop *server, size_t size, void *buf)
 	}
 
 	if (ret < 0)
-		glibtop_error_io_r (server, ngettext ("wrote %d byte", "wrote %d bytes", size), size);
+		glibtop_error_io_r (server,
+				    ngettext("wrote %d byte",
+					     "wrote %d bytes", size),
+				    (int) size);
 }
