@@ -475,10 +475,10 @@ read_filesystem_list (void)
 	mtail = me;
       }
 
-    if (ret > 0)
-      return NULL;
    if (fclose (fp) == EOF)
       return NULL;
+    if (ret > 0)
+      return NULL;
   }
 #endif /* MOUNTED_GETMNTENT2.  */
 
@@ -610,7 +610,7 @@ glibtop_get_mountlist_s (glibtop *server, glibtop_mountlist *buf, int all_fs)
 	buf->total  = buf->number * buf->size;
 
 	buf->flags  = (1 << GLIBTOP_MOUNTLIST_SIZE)
-	  | (1 << GLIBTOP_MOUNTLIST_SIZE)
+	  | (1 << GLIBTOP_MOUNTLIST_NUMBER)
 	  | (1 << GLIBTOP_MOUNTLIST_TOTAL);
 
 	return (glibtop_mountentry*) g_array_free(mount_array, FALSE);
