@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.35 2005/07/09 21:09:15 bdejean Exp $ */
+/* $Id: netload.c,v 1.38 2006/07/27 18:26:38 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -500,6 +500,10 @@ glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
 		buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_MULTICAST);
 	    }
 
+	g_strlcpy (ifr.ifr_name, interface, sizeof ifr.ifr_name);
+	if (!ioctl(skfd, /* SIOCGIWNAME */ 0x8B01, &ifr))
+		buf->if_flags |= (1L << GLIBTOP_IF_FLAGS_WIRELESS);
+
 	g_strlcpy (ifr.ifr_name, interface, sizeof ifr.ifr_name);
 	if (!ioctl (skfd, SIOCGIFADDR, &ifr)) {
 	    buf->address = ((struct sockaddr_in *) &ifr.ifr_addr)->sin_addr.s_addr;
@@ -540,10 +544,12 @@ glibtop_get_netload_s (glibtop *server, glibtop_netload *buf,
     if (server->os_version_code < LINUX_VERSION_CODE(2, 1, 14)) {
 	linux_2_0_stats(server, buf, interface);
     }
-    else if (server->os_version_code > LINUX_VERSION_CODE(2, 6, 0)) {
+    else if (server->os_version_code > LINUX_VERSION_CODE(2, 6, 0)
+	     && has_sysfs()) {
 	linux_2_6_stats(server, buf, interface);
     }
-    else if (server->os_version_code > LINUX_VERSION_CODE(2, 4, 0)) {
+    else {
+	/* 2.4 and 2.6 without /sys (?$£Z¥!) */
 	linux_2_4_stats(server, buf, interface);
     }
 
