@@ -1,4 +1,4 @@
-/* $Id: shm_limits.c,v 1.17 2004/06/12 12:05:49 bdejean Exp $ */
+/* $Id: shm_limits.c,v 1.20 2006/04/02 09:16:20 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop/shm_limits.h>
 
 #include <sys/ipc.h>
@@ -50,13 +51,12 @@ glibtop_get_shm_limits_s (glibtop *server, glibtop_shm_limits *buf)
 
 	memset (buf, 0, sizeof (glibtop_shm_limits));
 
-	buf->flags = _glibtop_sysdeps_shm_limits;
-
-	shmctl (0, IPC_INFO, (struct shmid_ds *) &shminfo);
+	shmctl (0, IPC_INFO, (void *) &shminfo);
 
 	buf->shmmax = shminfo.shmmax;
 	buf->shmmin = shminfo.shmmin;
 	buf->shmmni = shminfo.shmmni;
 	buf->shmseg = shminfo.shmseg;
 	buf->shmall = shminfo.shmall;
+	buf->flags = _glibtop_sysdeps_shm_limits;
 }
