@@ -1,4 +1,4 @@
-/* $Id: glibtop_server.h,v 1.7 2003/10/19 16:55:46 carlos Exp $ */
+/* $Id: glibtop_server.h,v 1.9 2005/08/12 14:55:37 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,7 +24,7 @@
 #ifndef __GLIBTOP_SERVER_H__
 #define __GLIBTOP_SERVER_H__
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_SUID_CPU		0
 #define GLIBTOP_SUID_MEM		0
@@ -45,8 +45,9 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_SUID_PROC_ARGS		0
 #define GLIBTOP_SUID_PROC_MAP		0
 #define GLIBTOP_SUID_NETLOAD		0
+#define GLIBTOP_SUID_NETLIST		0
 #define GLIBTOP_SUID_PPP		0
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
