@@ -1,4 +1,4 @@
-/* $Id: glibtop_server.h,v 1.9 2003/10/20 15:20:16 hadess Exp $ */
+/* $Id: glibtop_server.h,v 1.10 2006/04/04 20:06:14 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -42,7 +42,11 @@ G_BEGIN_DECLS
 #define GLIBTOP_SUID_PROC_SIGNAL	(1 << GLIBTOP_SYSDEPS_PROC_SIGNAL)
 #define GLIBTOP_SUID_PROC_KERNEL	(1 << GLIBTOP_SYSDEPS_PROC_KERNEL)
 #define GLIBTOP_SUID_PROC_SEGMENT	(1 << GLIBTOP_SYSDEPS_PROC_SEGMENT)
+#define GLIBTOP_SUID_PROC_ARGS		0
 #define GLIBTOP_SUID_PROC_MAP		(1 << GLIBTOP_SYSDEPS_PROC_MAP)
+#define GLIBTOP_SUID_NETLOAD		0
+#define GLIBTOP_SUID_NETLIST		0
+#define GLIBTOP_SUID_PPP		0
 
 G_END_DECLS
 
